%define libdrm_version %(rpm -q --qf='%{VERSION}' libdrm | %__awk 'BEGIN{FS="."}{print $1*10000+$2*100+$3}')
%if 0%{?libdrm_version} >= 020423
%define with_i965 1
%else
%define with_i965 0
%endif

#
# spec file for package libva
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define driver_version 1.0.17
%define lib_version 1.0.15

Name:           libva
Version:        %{lib_version}
Release:        19.4
Summary:        Video Acceleration (VA) API for Linux
License:        MIT
Group:          System/Libraries
Url:            http://freedesktop.org/wiki/Software/vaapi
Source0:        http://cgit.freedesktop.org/libva/snapshot/%{name}-%{lib_version}.tar.bz2
Source1:        http://cgit.freedesktop.org/vaapi/intel-driver/snapshot/intel-driver-%{driver_version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
# pkgconfig(libdrm_intel) currently only exists on x86*
ExclusiveArch:  %ix86 x86_64

%description
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

%package -n libva1
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries

%description -n libva1
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

%package devel
Summary:        Video Acceleration (VA) API for Linux -- development files
Group:          Development/Languages/C and C++
Requires:       libva1 = %{version}

%description devel
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This package provides the development environment for libva.

%package -n vaapi-tools
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries

%description -n vaapi-tools
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This is a set of tools around vaapi livrary.

%package -n vaapi-drivers
Version:        %{driver_version}
Release:        19.4
Summary:        Video Acceleration (VA) API for Linux
Group:          System/Libraries

%description -n vaapi-drivers
The libva library implements the Video Acceleration (VA) API for Linux.
The library loads a hardware dependendent driver.

This contains the dummy and hardware drivers.

%prep
%setup -q -n vaapi -c -a 0 -a 1

%build
pushd libva-%{lib_version}
autoreconf -v --install
%configure --enable-dummy-driver \
%if 0%{?suse_version} >= 01120
           --enable-dummy-backend \
%endif
           --enable-glx \
           --enable-egl \
           --with-drivers-path=%{_libdir}/dri
make %{?_smp_mflags}
popd
%if %with_i965
pushd intel-driver-%{driver_version}
export PKG_CONFIG_PATH="%{_builddir}/vaapi/libva-%{lib_version}/pkgconfig:$PKG_CONFIG_PATH"
autoreconf -v --install
%configure 
popd
%endif

%install
pushd libva-%{lib_version}
%makeinstall
popd
find %{buildroot} -name '*.la' -delete -print
%if %with_i965
pushd intel-driver-%{driver_version}
make %{?_smp_mflags} CPPFLAGS="-I%{buildroot}%{_includedir}" \
	LDFLAGS="-L%{buildroot}%{_libdir}"
%makeinstall
popd

find %{buildroot} -name '*.la' -delete -print
%endif

%post -n libva1 -p /sbin/ldconfig

%postun -n libva1 -p /sbin/ldconfig

%files -n vaapi-tools
%defattr(-,root,root,-)
%{_bindir}/vainfo
%{_bindir}/avcenc
%{_bindir}/h264encode
%{_bindir}/mpeg2vldemo
%{_bindir}/putsurface

%files -n vaapi-drivers
%defattr(-,root,root,-)
%dir %{_libdir}/dri
%{_libdir}/dri/dummy_drv_video.so
%if %with_i965
%{_libdir}/dri/i965_drv_video.so
%endif

%files -n libva1
%defattr(-, root, root)
%{_libdir}/libva.so.*
%{_libdir}/libva-tpi.so.*
%{_libdir}/libva-x11.so.*
%{_libdir}/libva-glx.so.*
%{_libdir}/libva-egl.so.*
%if 0%{?suse_version} >= 01120
%{_libdir}/libva-dummy.so.*
%endif

%files devel
%defattr(-,root,root,-)
%{_libdir}/libva.so
%{_libdir}/libva-tpi.so
%{_libdir}/libva-x11.so
%{_libdir}/libva-glx.so
%{_libdir}/libva-egl.so
%if 0%{?suse_version} >= 01120
%{_libdir}/libva-dummy.so
%endif
%{_includedir}/va
%{_libdir}/pkgconfig/libva*.pc

%changelog
* Fri Apr 13 2012 kkhere.geo@gmail.com
- update intel driver to version 1.0.17
  Version 1.0.17 - 02.Apr.2012
  * Add support for IMC1/IMC3 surface formats
  * Fix rendering of interlaced surfaces
  * Fix MPEG-2 decoding of interlaced streams (SNB, IVB)
  * Fix H.264 weighted prediction indicator (SNB)
  * Fix and simplify calculation of H.264 macroblock bit offset (ILK, SNB, IVB)
  Version 1.0.16 - 14.Feb.2012
  * Fix VC-1 bitplane buffer size (SNB, IVB)
  * Fix VC-1 motion vector modes for Ivy Bridge
  * Fix MFX_QM_STATE for H.264 flat scaling lists (IVB)
  * Fix and simplify AVC_REF_IDX_STATE setup (ILK, SNB, IVB)
  * Fix memory leak of encoder buffers
  * Fix check for internal VA surface format prior to rendering
  * Add support for B43 chipset (Alexander Inyukhin)
* Wed Mar 21 2012 jengelh@medozas.de
- Remove redundant sections, compress filelist
- Enable parallel build
- Use pkgconfig symbols for deps
* Mon Feb 27 2012 dmueller@suse.de
- exclude from build on ARM
* Tue Feb 14 2012 sndirsch@suse.com
- Update package BuildRequires to use pkgconfig symbols
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Nov  9 2011 kkhere.geo@gmail.com
- new version 1.0.15
  * API: make {Top,Bottom}FieldOrderCnt signed (Yi Wang)
  * Add auto-generated Debian packaging
  * Refine VA trace & VA fool utilities
  * Move i965 driver to a specific repository (vaapi/intel-driver)
  * Fix DSO link issue in tests
  * Fix fglrx driver name detection
  * Fix API vs. DSO vs. package versioning
- intel-driver has been split from the library, use separate tarball
- split the drivers into a separate package
* Tue Aug  9 2011 kkhere.geo@gmail.com
- new version 1.0.14
  no NEWS released; changelog in git http://cgit.freedesktop.org/libva/
* Tue May 31 2011 kkhere.geo@gmail.com
- new version 1.0.13
  * cleans up licensing issue
  * IvyBrigde video decoding support
  * thread safety
  * Encoding support in SandyBridge
* Fri Apr  1 2011 kkhere.geo@gmail.com
- new version 1.0.12
* Mon Mar 28 2011 kkhere.geo@gmail.com
- new version 1.0.11
  * obsoletes patch
  - i965_dri_video: don't try to render an invalid surface
* Thu Mar  3 2011 kkhere.geo@gmail.com
- patch: i965_dri_video: don't try to render an invalid surface
* Tue Feb 15 2011 kkhere.geo@gmail.com
- new version 1.0.10
* Mon Jan 10 2011 kkhere.geo@gmail.com
- new version 1.0.7
- support IA44 AI44 subpicture format in sandybridge
* Sun Dec 19 2010 lnussel@suse.de
- new version 1.0.6
* Fri Nov  5 2010 kkhere.geo@gmail.com
- update to version 1.0.6
* Thu Sep 30 2010 kkhere.geo@gmail.com
- update to version 1.0.5
  * add scaling flags for vaPutSurface()
  * i965_drv_video: add video processing kernels
  * i965_drv_video: deinterlacing & scaling
* Thu Sep  9 2010 kkhere.geo@gmail.com
- update to version 1.0.4
* Tue Jun  8 2010 dimstar@opensuse.org
- Split the library in libva1, the tools in vaapi-tools and the
  development in libva-devel. Both libraries can live in the same
  package as per policy: they are kept in sync with their soNUM.
* Mon Jun  7 2010 dominique-vlc.suse@leuenberger.net
- Initial package for VideoLAN repository, libva 1.0.1
